cheesecake.cheesecake_index.IndexFormattedDocstrings

Package cheesecake :: Module cheesecake_index :: Class IndexFormattedDocstrings |
[hide private]
[frames] | no frames]

## Class IndexFormattedDocstrings
source code

    object --+
             |
         Index --+
                 |
                IndexFormattedDocstrings

Compute how many of existing docstrings include any formatting, like epytext or reST.

Nested Classes | [hide private]
Inherited from `Index`: `__metaclass__`

Instance Methods | [hide private]
| compute(self, object_cnt, docformat_cnt) Compute index value and return it.
Inherited from `Index`: `__getitem__`, `__init__`, `add_info`, `add_subindex`, `compute_with`, `decide`, `decide_after_download`, `decide_before_download`, `get_info`, `print_info`, `remove_subindex` Inherited from `Index` (private): `_get_max_value`, `_get_requirements`, `_iter_indices`, `_print_info_many`, `_print_info_one` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
max_value |
name |
Inherited from `Index`: `details`, `info`, `subindices`, `value` Inherited from `object`: `__class__`

Properties | [hide private]
Inherited from `Index`: `requirements`

Method Details | [hide private]

### compute(self, object_cnt, docformat_cnt) | source code
Compute index value and return it. By default this method computes sum of all subindices. Override this method when subclassing for different behaviour. Parameters to this function are dynamically prepared with use of get_attributes function. Overrides: Index.compute (inherited documentation)

Class Variable Details | [hide private]

    ### max_value Value:
        30

    ### name Value:
        'IndexFormattedDocstrings'